package sysrand

import "crypto/internal/sysrand"

Package rand provides cryptographically secure random bytes from the operating system.

Index

Functions

func Read

func Read(b []byte)

Read fills b with cryptographically secure random bytes from the operating system. It always fills b entirely and crashes the program irrecoverably if an error is encountered. The operating system APIs are documented to never return an error on all but legacy Linux systems.

Note that Read is not affected by testing/cryptotest.SetGlobalRand, and it should not be used directly by algorithm implementations.

Source Files

rand.go rand_getrandom.go

Directories

PathSynopsis
crypto/internal/sysrand/internal
crypto/internal/sysrand/internal/seccomp
Version
v1.26.0-rc.1
Published
Dec 15, 2025
Platform
linux/amd64
Imports
10 packages
Last checked
23 seconds ago

Tools for package owners.